@@ -1,25 +1,9 @@
 /*
-  Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2007 Loïc Corbasson <loic.corbasson@gmail.com>
+  SPDX-FileCopyrightText: 2000, 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2007 Loïc Corbasson <loic.corbasson@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef EVENTVIEWS_DECORATIONLABEL_H
 #define EVENTVIEWS_DECORATIONLABEL_H
@@ -56,9 +40,11 @@ protected:
     void resizeEvent(QResizeEvent *) override;
     void mouseReleaseEvent(QMouseEvent *) override;
     virtual void squeezeContentsToLabel();
-    bool mAutomaticSqueeze;
+    bool mAutomaticSqueeze = true;
     EventViews::CalendarDecoration::Element *mDecorationElement = nullptr;
-    QString mShortText, mLongText, mExtensiveText;
+    QString mShortText;
+    QString mLongText;
+    QString mExtensiveText;
     QPixmap mPixmap;
     QUrl mUrl;
 };
