@@ -1,27 +1,11 @@
 /*
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
-  Author: Sergio Martins, sergio.martins@kdab.com
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
+  SPDX-FileContributor: Sergio Martins <sergio@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "eventview_p.h"
@@ -36,8 +20,7 @@
 #include <EntityDisplayAttribute>
 #include <ETMViewStateSaver>
 
-#include <KCalCore/Todo>
-#include <KCalCore/CalFilter>
+#include <KCalendarCore/CalFilter>
 
 #include <KCalUtils/RecurrenceActions>
 
@@ -55,7 +38,7 @@
 #include <QKeyEvent>
 #include <QSortFilterProxyModel>
 
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace EventViews;
 using namespace Akonadi;
 
@@ -115,7 +98,7 @@ void EventView::setHolidayRegions(const QStringList &regions)
     qDeleteAll(d->mHolidayRegions);
     d->mHolidayRegions.clear();
     for (const QString &regionStr : regions) {
-        KHolidays::HolidayRegion *region = new KHolidays::HolidayRegion(regionStr);
+        auto *region = new KHolidays::HolidayRegion(regionStr);
         if (region->isValid()) {
             d->mHolidayRegions.append(region);
         } else {
@@ -546,7 +529,7 @@ void EventView::restoreConfig(const KConfigGroup &configGroup)
     } else if (useCustom) {
         if (!d->collectionSelectionModel) {
             // Sort the calendar model on calendar name
-            QSortFilterProxyModel *sortProxy = new QSortFilterProxyModel(this);
+            auto *sortProxy = new QSortFilterProxyModel(this);
             sortProxy->setDynamicSortFilter(true);
             sortProxy->setSortCaseSensitivity(Qt::CaseInsensitive);
 
@@ -555,7 +538,7 @@ void EventView::restoreConfig(const KConfigGroup &configGroup)
             }
 
             // Only show the first column.
-            KRearrangeColumnsProxyModel *columnFilterProxy = new KRearrangeColumnsProxyModel(this);
+            auto *columnFilterProxy = new KRearrangeColumnsProxyModel(this);
             columnFilterProxy->setSourceColumns(
                 QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
             columnFilterProxy->setSourceModel(sortProxy);
@@ -608,20 +591,20 @@ Akonadi::Collection::Id EventView::collectionId() const
     return d->mCollectionId;
 }
 
-bool EventView::makesWholeDayBusy(const KCalCore::Incidence::Ptr &incidence) const
+bool EventView::makesWholeDayBusy(const KCalendarCore::Incidence::Ptr &incidence) const
 {
     // Must be event
     // Must be all day
     // Must be marked busy (TRANSP: OPAQUE)
     // You must be attendee or organizer
 
-    if (incidence->type() != KCalCore::Incidence::TypeEvent || !incidence->allDay()) {
+    if (incidence->type() != KCalendarCore::Incidence::TypeEvent || !incidence->allDay()) {
         return false;
     }
 
-    KCalCore::Event::Ptr ev = incidence.staticCast<KCalCore::Event>();
+    KCalendarCore::Event::Ptr ev = incidence.staticCast<KCalendarCore::Event>();
 
-    if (ev->transparency() != KCalCore::Event::Opaque) {
+    if (ev->transparency() != KCalendarCore::Event::Opaque) {
         return false;
     }
 
@@ -631,8 +614,8 @@ bool EventView::makesWholeDayBusy(const KCalCore::Incidence::Ptr &incidence) con
         return true;
     }
 
-    KCalCore::Attendee::List attendees = ev->attendees();
-    KCalCore::Attendee::List::ConstIterator it;
+    KCalendarCore::Attendee::List attendees = ev->attendees();
+    KCalendarCore::Attendee::List::ConstIterator it;
     for (it = attendees.constBegin(); it != attendees.constEnd(); ++it) {
         if (kcalPreferences()->thatIsMe((*it).email())) {
             return true;
