@@ -1,27 +1,11 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2007 Mike McQuaid <mike@mikemcquaid.com>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2007 Mike McQuaid <mike@mikemcquaid.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 // Journal Entry
@@ -30,10 +14,9 @@
 
 #include <CalendarSupport/Utils>
 
-#include <KCalCore/Journal>
+#include <KCalendarCore/Journal>
 
 #include <KCalUtils/IncidenceFormatter>
-#include <Akonadi/Calendar/ETMCalendar>
 
 #include <QTextBrowser>
 #include <KLocalizedString>
@@ -49,7 +32,6 @@ using namespace EventViews;
 JournalDateView::JournalDateView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent)
     : QFrame(parent)
     , mCalendar(calendar)
-    , mChanger(nullptr)
 {
     auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
@@ -82,9 +64,9 @@ void JournalDateView::addJournal(const Akonadi::Item &j)
 
     QWidget *container = new QWidget(this);
     layout()->addWidget(container);
-    QHBoxLayout *layout = new QHBoxLayout(container);
+    auto *layout = new QHBoxLayout(container);
     layout->addStretch(1);
-    JournalFrame *entry = new JournalFrame(j, mCalendar, this);
+    auto *entry = new JournalFrame(j, mCalendar, this);
     layout->addWidget(entry, 3 /*stretch*/);
     layout->addStretch(1);
 
@@ -103,8 +85,8 @@ void JournalDateView::addJournal(const Akonadi::Item &j)
             this, &JournalDateView::editIncidence);
     connect(entry, &JournalFrame::incidenceSelected,
             this, &JournalDateView::incidenceSelected);
-    connect(entry, SIGNAL(printJournal(KCalCore::Journal::Ptr,bool)),
-            SIGNAL(printJournal(KCalCore::Journal::Ptr,bool)));
+    connect(entry, QOverload<const KCalendarCore::Journal::Ptr &, bool>::of(&JournalFrame::printJournal),
+            this, QOverload<const KCalendarCore::Journal::Ptr &, bool>::of(&JournalDateView::printJournal));
 }
 
 Akonadi::Item::List JournalDateView::journals() const
@@ -158,14 +140,14 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::ETMCalendar::P
     mWriteInProgress = false;
     mChanger = nullptr;
 
-    QVBoxLayout *verticalLayout = new QVBoxLayout(this);
+    auto *verticalLayout = new QVBoxLayout(this);
 
     mBrowser = new QTextBrowser(this);
     mBrowser->viewport()->installEventFilter(this);
     mBrowser->setFrameStyle(QFrame::NoFrame);
     verticalLayout->addWidget(mBrowser);
 
-    QHBoxLayout *buttonsLayout = new QHBoxLayout();
+    auto *buttonsLayout = new QHBoxLayout();
     verticalLayout->addLayout(buttonsLayout);
     buttonsLayout->addStretch();
 
@@ -300,7 +282,7 @@ void JournalFrame::readJournal(const Akonadi::Item &j)
 {
     int baseFontSize = QFontDatabase::systemFont(QFontDatabase::GeneralFont).pointSize();
     mJournal = j;
-    const KCalCore::Journal::Ptr journal = CalendarSupport::journal(j);
+    const KCalendarCore::Journal::Ptr journal = CalendarSupport::journal(j);
     mBrowser->clear();
     QTextCursor cursor = QTextCursor(mBrowser->textCursor());
     cursor.movePosition(QTextCursor::Start);
