@@ -1,29 +1,14 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bruno.virlet@gmail.com>
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bruno.virlet@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "monthscene.h"
 #include "monthgraphicsitems.h"
 #include "monthitem.h"
 #include "monthview.h"
+#include "helper.h"
 #include "prefs.h"
 
 #include <CalendarSupport/Utils>
@@ -80,7 +65,7 @@ MonthCell *MonthScene::previousCell() const
     return mPreviousCell;
 }
 
-int MonthScene::getRightSpan(const QDate &date) const
+int MonthScene::getRightSpan(QDate date) const
 {
     MonthCell *cell = mMonthCellMap.value(date);
     if (!cell) {
@@ -90,7 +75,7 @@ int MonthScene::getRightSpan(const QDate &date) const
     return 7 - cell->x() - 1;
 }
 
-int MonthScene::getLeftSpan(const QDate &date) const
+int MonthScene::getLeftSpan(QDate date) const
 {
     MonthCell *cell = mMonthCellMap.value(date);
     if (!cell) {
@@ -257,11 +242,12 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
                 color = palette().color(QPalette::AlternateBase);
             }
         }
+        const bool usingDark = EventViews::isColorDark(color);
         if (cell == mScene->selectedCell()) {
-            color = color.darker(115);
+            color = (usingDark) ? color.lighter(150) : color.darker(115);
         }
         if (cell->date() == QDate::currentDate()) {
-            color = color.darker(140);
+            color = (usingDark) ? color.lighter(200) : color.darker(140);
         }
 
         // Draw cell
@@ -286,7 +272,8 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
         QLinearGradient bgGradient(QPointF(cellHeaderX, cellHeaderY),
                                    QPointF(cellHeaderX + cellHeaderWidth,
                                            cellHeaderY + cellHeaderHeight));
-        if ((color.blue() + color.red() + color.green()) > (256 / 2 * 3)) {
+        // Compute color of grid lines based on dark/lightness
+        if (!usingDark) {
             p->setBrush(color.darker(110));
         } else {
             p->setBrush(color.lighter(140));
@@ -509,7 +496,7 @@ void MonthScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
     MonthGraphicsItem *iItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos, {}));
     if (iItem) {
         if (iItem->monthItem()) {
-            IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(iItem->monthItem());
+            auto *tmp = qobject_cast<IncidenceMonthItem *>(iItem->monthItem());
             if (tmp) {
                 selectItem(iItem->monthItem());
                 mMonthView->defaultAction(tmp->akonadiItem());
@@ -597,7 +584,7 @@ void MonthScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
 
         selectItem(mClickedItem);
         if (mouseEvent->button() == Qt::RightButton) {
-            IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(mClickedItem);
+            auto *tmp = qobject_cast<IncidenceMonthItem *>(mClickedItem);
             if (tmp) {
                 Q_EMIT showIncidencePopupSignal(tmp->akonadiItem(), tmp->realStartDate());
             }
@@ -738,7 +725,7 @@ void MonthScene::selectItem(MonthItem *item)
       Another solution would be to have two Q_SIGNALS: incidenceSelected() and incidenceClicked()
     */
 
-    IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(item);
+    auto *tmp = qobject_cast<IncidenceMonthItem *>(item);
 
     if (!tmp) {
         mSelectedItem = nullptr;
@@ -760,7 +747,7 @@ void MonthScene::selectItem(MonthItem *item)
 void MonthScene::removeIncidence(const QString &uid)
 {
     for (MonthItem *manager : qAsConst(mManagerList)) {
-        IncidenceMonthItem *imi = qobject_cast<IncidenceMonthItem *>(manager);
+        auto *imi = qobject_cast<IncidenceMonthItem *>(manager);
         if (!imi) {
             continue;
         }
