@@ -1,27 +1,10 @@
 /*
-  Copyright (c) 2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
 
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "prefs.h"
 #include "prefs_base.h"
@@ -64,6 +47,7 @@ QByteArray iconSetToArray(const QSet<EventViews::EventView::ItemIcon> &set)
 QByteArray agendaViewIconDefaults()
 {
     QByteArray iconDefaults;
+    iconDefaults.resize(7);
 
     iconDefaults[EventViews::EventView::CalendarCustomIcon] = 1;
     iconDefaults[EventViews::EventView::TaskIcon] = 1;
@@ -79,6 +63,7 @@ QByteArray agendaViewIconDefaults()
 QByteArray monthViewIconDefaults()
 {
     QByteArray iconDefaults;
+    iconDefaults.resize(7);
 
     iconDefaults[EventViews::EventView::CalendarCustomIcon] = 1;
     iconDefaults[EventViews::EventView::TaskIcon] = 1;
@@ -290,7 +275,7 @@ void Prefs::Private::setBool(KCoreConfigSkeleton::ItemBool *baseConfigItem, bool
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemBool *item
+        auto *item
             = dynamic_cast<KCoreConfigSkeleton::ItemBool *>(appItem);
         if (item) {
             item->setValue(value);
@@ -307,7 +292,7 @@ bool Prefs::Private::getBool(const KCoreConfigSkeleton::ItemBool *baseConfigItem
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemBool *item
+        auto *item
             = dynamic_cast<KCoreConfigSkeleton::ItemBool *>(appItem);
         if (item) {
             return item->value();
@@ -322,7 +307,7 @@ void Prefs::Private::setInt(KCoreConfigSkeleton::ItemInt *baseConfigItem, int va
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemInt *item = dynamic_cast<KCoreConfigSkeleton::ItemInt *>(appItem);
+        auto *item = dynamic_cast<KCoreConfigSkeleton::ItemInt *>(appItem);
         if (item) {
             item->setValue(value);
         } else {
@@ -338,7 +323,7 @@ int Prefs::Private::getInt(const KCoreConfigSkeleton::ItemInt *baseConfigItem) c
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemInt *item = dynamic_cast<KCoreConfigSkeleton::ItemInt *>(appItem);
+        auto *item = dynamic_cast<KCoreConfigSkeleton::ItemInt *>(appItem);
         if (item) {
             return item->value();
         }
@@ -353,7 +338,7 @@ void Prefs::Private::setString(KCoreConfigSkeleton::ItemString *baseConfigItem,
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemString *item
+        auto *item
             = dynamic_cast<KCoreConfigSkeleton::ItemString *>(appItem);
 
         if (item) {
@@ -371,7 +356,7 @@ QString Prefs::Private::getString(const KCoreConfigSkeleton::ItemString *baseCon
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemString *item
+        auto *item
             = dynamic_cast<KCoreConfigSkeleton::ItemString *>(appItem);
 
         if (item) {
@@ -388,7 +373,7 @@ void Prefs::Private::setDateTime(KCoreConfigSkeleton::ItemDateTime *baseConfigIt
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemDateTime *item
+        auto *item
             = dynamic_cast<KCoreConfigSkeleton::ItemDateTime *>(appItem);
 
         if (item) {
@@ -407,7 +392,7 @@ QDateTime Prefs::Private::getDateTime(
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemDateTime *item
+        auto *item
             = dynamic_cast<KCoreConfigSkeleton::ItemDateTime *>(appItem);
 
         if (item) {
@@ -424,7 +409,7 @@ void Prefs::Private::setStringList(KCoreConfigSkeleton::ItemStringList *baseConf
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemStringList *item
+        auto *item
             = dynamic_cast<KCoreConfigSkeleton::ItemStringList *>(appItem);
 
         if (item) {
@@ -443,7 +428,7 @@ QStringList Prefs::Private::getStringList(
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KCoreConfigSkeleton::ItemStringList *item
+        auto *item
             = dynamic_cast<KCoreConfigSkeleton::ItemStringList *>(appItem);
 
         if (item) {
@@ -459,7 +444,7 @@ void Prefs::Private::setColor(KConfigSkeleton::ItemColor *baseConfigItem, const
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KConfigSkeleton::ItemColor *item = dynamic_cast<KConfigSkeleton::ItemColor *>(appItem);
+        auto *item = dynamic_cast<KConfigSkeleton::ItemColor *>(appItem);
         if (item) {
             item->setValue(value);
         } else {
@@ -475,7 +460,7 @@ QColor Prefs::Private::getColor(const KConfigSkeleton::ItemColor *baseConfigItem
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KConfigSkeleton::ItemColor *item = dynamic_cast<KConfigSkeleton::ItemColor *>(appItem);
+        auto *item = dynamic_cast<KConfigSkeleton::ItemColor *>(appItem);
         if (item) {
             return item->value();
         }
@@ -489,7 +474,7 @@ void Prefs::Private::setFont(KConfigSkeleton::ItemFont *baseConfigItem, const QF
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KConfigSkeleton::ItemFont *item = dynamic_cast<KConfigSkeleton::ItemFont *>(appItem);
+        auto *item = dynamic_cast<KConfigSkeleton::ItemFont *>(appItem);
         if (item) {
             item->setValue(value);
         } else {
@@ -505,7 +490,7 @@ QFont Prefs::Private::getFont(const KConfigSkeleton::ItemFont *baseConfigItem) c
 {
     KConfigSkeletonItem *appItem = appConfigItem(baseConfigItem);
     if (appItem) {
-        KConfigSkeleton::ItemFont *item = dynamic_cast<KConfigSkeleton::ItemFont *>(appItem);
+        auto *item = dynamic_cast<KConfigSkeleton::ItemFont *>(appItem);
         if (item) {
             return item->value();
         }
