@@ -1,24 +1,8 @@
 /*
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Sérgio Martins <sergio.martins@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Sérgio Martins <sergio.martins@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef EVENTVIEWS_TIMELINEVIEW_P_H
 #define EVENTVIEWS_TIMELINEVIEW_P_H
@@ -35,15 +19,11 @@
 class QStandardItem;
 class QTreeWidget;
 
-namespace KGantt
-{
+namespace KGantt {
 class GraphicsView;
 }
 
-
-namespace EventViews
-{
-
+namespace EventViews {
 class TimelineItem;
 class RowController;
 
@@ -51,7 +31,7 @@ class TimelineView::Private : public QObject
 {
     Q_OBJECT
 public:
-    explicit Private(TimelineView *parent = Q_NULLPTR);
+    explicit Private(TimelineView *parent = nullptr);
     ~Private();
 
     TimelineItem *calendarItemForIncidence(const Akonadi::Item &incidence);
@@ -70,9 +50,9 @@ public Q_SLOTS:
 
 public:
     Akonadi::Item::List mSelectedItemList;
-    KGantt::GraphicsView *mGantt;
-    QTreeWidget *mLeftView;
-    RowController *mRowController;
+    KGantt::GraphicsView *mGantt = nullptr;
+    QTreeWidget *mLeftView = nullptr;
+    RowController *mRowController = nullptr;
     QMap<Akonadi::Collection::Id, TimelineItem *> mCalendarItemMap;
     QDate mStartDate, mEndDate;
     QDateTime mHintDate;
@@ -80,7 +60,6 @@ public:
 private:
     TimelineView *const q;
 };
-
 } // namespace EventViews
 
 #endif
