@@ -1,29 +1,13 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
-  Copyright (c) 2013 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2000, 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2013 Sérgio Martins <iamsergio@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "todoview.h"
@@ -45,7 +29,7 @@
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
-#include <Libkdepim/KDatePickerPopup>
+#include <CalendarSupport/KDatePickerPopup>
 
 #include <KCalendarCore/CalFormat>
 
@@ -71,8 +55,6 @@ public:
         : todoModel(new TodoModel(preferences))
         , parent(parent_)
         , calendar(nullptr)
-        , todoTreeModel(nullptr)
-        , todoFlatModel(nullptr)
         , prefs(preferences)
     {
     }
@@ -237,20 +219,20 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     connect(mView, &TodoViewView::visibleColumnCountChanged,
             this, &TodoView::resizeColumns);
 
-    TodoRichTextDelegate *richTextDelegate = new TodoRichTextDelegate(mView);
+    auto *richTextDelegate = new TodoRichTextDelegate(mView);
     mView->setItemDelegateForColumn(TodoModel::SummaryColumn, richTextDelegate);
     mView->setItemDelegateForColumn(TodoModel::DescriptionColumn, richTextDelegate);
 
-    TodoPriorityDelegate *priorityDelegate = new TodoPriorityDelegate(mView);
+    auto *priorityDelegate = new TodoPriorityDelegate(mView);
     mView->setItemDelegateForColumn(TodoModel::PriorityColumn, priorityDelegate);
 
-    TodoDueDateDelegate *startDateDelegate = new TodoDueDateDelegate(mView);
+    auto *startDateDelegate = new TodoDueDateDelegate(mView);
     mView->setItemDelegateForColumn(TodoModel::StartDateColumn, startDateDelegate);
 
-    TodoDueDateDelegate *dueDateDelegate = new TodoDueDateDelegate(mView);
+    auto *dueDateDelegate = new TodoDueDateDelegate(mView);
     mView->setItemDelegateForColumn(TodoModel::DueDateColumn, dueDateDelegate);
 
-    TodoCompleteDelegate *completeDelegate = new TodoCompleteDelegate(mView);
+    auto *completeDelegate = new TodoCompleteDelegate(mView);
     mView->setItemDelegateForColumn(TodoModel::PercentColumn, completeDelegate);
 
     mCategoriesDelegate = new TodoCategoriesDelegate(mView);
@@ -299,7 +281,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
         connect(mFullViewButton, &QToolButton::toggled, this, &TodoView::setFullView);
     }
 
-    QGridLayout *layout = new QGridLayout(this);
+    auto *layout = new QGridLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     if (!mSidebarView) {
         layout->addWidget(mQuickSearch, 0, 0, 1, 2);
@@ -310,7 +292,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 
     // Dummy layout just to add a few px of right margin so the checkbox is aligned
     // with the QAbstractItemView's viewport.
-    QHBoxLayout *dummyLayout = new QHBoxLayout();
+    auto *dummyLayout = new QHBoxLayout();
     dummyLayout->setContentsMargins(0, 0, mView->frameWidth() /*right*/, 0);
     if (!mSidebarView) {
         QFrame *f = new QFrame(this);
@@ -399,25 +381,25 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 
     mItemPopupMenu->addSeparator();
 
-    mCopyPopupMenu = new KPIM::KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
-                                                |KPIM::KDatePickerPopup::DatePicker
-                                                |KPIM::KDatePickerPopup::Words,
+    mCopyPopupMenu = new CalendarSupport::KDatePickerPopup(CalendarSupport::KDatePickerPopup::NoDate
+                                                |CalendarSupport::KDatePickerPopup::DatePicker
+                                                |CalendarSupport::KDatePickerPopup::Words,
                                                 QDate::currentDate(), this);
     mCopyPopupMenu->setTitle(i18nc("@title:menu", "&Copy To"));
 
-    connect(mCopyPopupMenu, &KPIM::KDatePickerPopup::dateChanged, this, &TodoView::copyTodoToDate);
+    connect(mCopyPopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::copyTodoToDate);
 
-    connect(mCopyPopupMenu, &KPIM::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
+    connect(mCopyPopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
-    mMovePopupMenu = new KPIM:: KDatePickerPopup(KPIM::KDatePickerPopup::NoDate
-                                                 |KPIM::KDatePickerPopup::DatePicker
-                                                 |KPIM::KDatePickerPopup::Words,
+    mMovePopupMenu = new CalendarSupport:: KDatePickerPopup(CalendarSupport::KDatePickerPopup::NoDate
+                                                 |CalendarSupport::KDatePickerPopup::DatePicker
+                                                 |CalendarSupport::KDatePickerPopup::Words,
                                                  QDate::currentDate(), this);
     mMovePopupMenu->setTitle(i18nc("@title:menu", "&Move To"));
 
-    connect(mMovePopupMenu, &KPIM::KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
+    connect(mMovePopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
 
-    connect(mMovePopupMenu, &KPIM::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
+    connect(mMovePopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
     mItemPopupMenu->insertMenu(nullptr, mCopyPopupMenu);
     mItemPopupMenu->insertMenu(nullptr, mMovePopupMenu);
@@ -903,7 +885,7 @@ void TodoView::itemDoubleClicked(const QModelIndex &index)
 
 QMenu *TodoView::createCategoryPopupMenu()
 {
-    QMenu *tempMenu = new QMenu(this);
+    auto *tempMenu = new QMenu(this);
 
     QModelIndexList selection = mView->selectionModel()->selectedRows();
     if (selection.size() != 1) {
@@ -916,7 +898,7 @@ QMenu *TodoView::createCategoryPopupMenu()
 
     const QStringList checkedCategories = todo->categories();
 
-    Akonadi::TagFetchJob *tagFetchJob = new Akonadi::TagFetchJob(this);
+    auto *tagFetchJob = new Akonadi::TagFetchJob(this);
     connect(tagFetchJob, &Akonadi::TagFetchJob::result, this, &TodoView::onTagsFetched);
     tagFetchJob->setProperty("menu", QVariant::fromValue(QPointer<QMenu>(tempMenu)));
     tagFetchJob->setProperty("checkedCategories", checkedCategories);
@@ -932,7 +914,7 @@ void TodoView::onTagsFetched(KJob *job)
         qCWarning(CALENDARVIEW_LOG) << "Failed to fetch tags " << job->errorString();
         return;
     }
-    Akonadi::TagFetchJob *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
+    auto *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
     const QStringList checkedCategories = job->property("checkedCategories").toStringList();
     QPointer<QMenu> menu = job->property("menu").value<QPointer<QMenu> >();
     if (menu) {
