@@ -1,42 +1,24 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2004 Till Adam <adam@kde.org>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2004 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "todoviewquicksearch.h"
 #include <CalendarSupport/KCalPrefs>
 
-#include <Akonadi/Calendar/ETMCalendar>
+#include <AkonadiWidgets/TagSelectionComboBox>
 #include <CalendarSupport/CategoryConfig>
 
 #include <Libkdepim/KCheckComboBox>
-#include <LibkdepimAkonadi/TagSelectionCombo>
 
 #include <CalendarSupport/CategoryHierarchyReader>
 
-#include <KCalCore/CalFilter>
+#include <KCalendarCore/CalFilter>
 
 #include <QLineEdit>
 #include <KLocalizedString>
@@ -47,7 +29,7 @@ TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calend
     : QWidget(parent)
     , mCalendar(calendar)
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
     // no special margin because it is added by the view
     layout->setContentsMargins(0, 0, 0, 0);
 
@@ -63,7 +45,8 @@ TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calend
 
     layout->addWidget(mSearchLine, 3);
 
-    mCategoryCombo = new KPIM::TagSelectionCombo(this);
+    mCategoryCombo = new Akonadi::TagSelectionComboBox(this);
+    mCategoryCombo->setCheckable(true);
     mCategoryCombo->setToolTip(
         i18nc("@info:tooltip", "Filter on these categories"));
     mCategoryCombo->setWhatsThis(
@@ -71,11 +54,12 @@ TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calend
               "Use this combobox to filter the to-dos that are shown by "
               "a list of selected categories."));
     const QString defaultText = i18nc("@item:inlistbox", "Select Categories");
-    mCategoryCombo->setDefaultText(defaultText);
-    mCategoryCombo->setSeparator(i18nc("@item:intext delimiter for joining category names", ","));
+    mCategoryCombo->lineEdit()->setPlaceholderText(defaultText);
 
-    connect(mCategoryCombo, &KPIM::TagSelectionCombo::checkedItemsChanged, this,
-            &TodoViewQuickSearch::emitFilterCategoryChanged);
+    connect(mCategoryCombo, &Akonadi::TagSelectionComboBox::selectionChanged,
+            this, [this]() {
+                Q_EMIT filterCategoryChanged(mCategoryCombo->selectionNames());
+            });
 
     layout->addWidget(mCategoryCombo, 1);
 
@@ -103,8 +87,10 @@ TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calend
               "Use this combobox to filter the to-dos that are shown by "
               "a list of selected priorities."));
     mPriorityCombo->setDefaultText(i18nc("@item:inlistbox", "Select Priority"));
-    connect(mPriorityCombo, &KPIM::KCheckComboBox::checkedItemsChanged, this,
-            &TodoViewQuickSearch::emitFilterPriorityChanged);
+    connect(mPriorityCombo, &KPIM::KCheckComboBox::checkedItemsChanged,
+            this, [this]() {
+                Q_EMIT filterPriorityChanged(mPriorityCombo->checkedItems(Qt::UserRole));
+            });
 
     layout->addWidget(mPriorityCombo, 1);
     fillPriorities();
@@ -142,12 +128,3 @@ void TodoViewQuickSearch::fillPriorities()
     CalendarSupport::CategoryHierarchyReaderQComboBox(mPriorityCombo).read(priorityValues);
 }
 
-void TodoViewQuickSearch::emitFilterCategoryChanged()
-{
-    Q_EMIT filterCategoryChanged(mCategoryCombo->checkedItems());
-}
-
-void TodoViewQuickSearch::emitFilterPriorityChanged()
-{
-    Q_EMIT filterPriorityChanged(mPriorityCombo->checkedItems(Qt::UserRole));
-}
