@@ -1,25 +1,9 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "whatsnextview.h"
@@ -30,7 +14,6 @@
 
 #include <KCalUtils/IncidenceFormatter>
 
-#include <KIconLoader>
 
 #include <QBoxLayout>
 
@@ -75,7 +58,7 @@ void WhatsNextView::createTaskRow(KIconLoader *kil)
                   KIconLoader::DefaultState, QStringList(), &ipath);
     mText += QLatin1String("<h2><img src=\"");
     mText += ipath;
-    mText += QLatin1String("\" width=\"22\" height=\"22\">");
+    mText += QLatin1String(R"(" width="22" height="22">)");
     mText += i18n("To-dos:") + QLatin1String("</h2>\n");
     mText += QLatin1String("<ul>\n");
 }
@@ -91,7 +74,7 @@ void WhatsNextView::updateView()
     mText += QLatin1String("<tr bgcolor=\"#3679AD\"><td><h1>");
     mText += QLatin1String("<img src=\"");
     mText += ipath;
-    mText += QLatin1String("\" width=\"32\" height=\"32\">");
+    mText += QLatin1String(R"(" width="32" height="32">)");
     mText += QLatin1String("<font color=\"white\"> ");
     mText += i18n("What's Next?") + QLatin1String("</font></h1>");
     mText += QLatin1String("</td></tr>\n<tr><td>");
@@ -118,7 +101,7 @@ void WhatsNextView::updateView()
                       KIconLoader::DefaultState, QStringList(), &ipath);
         mText += QLatin1String("<h2><img src=\"");
         mText += ipath;
-        mText += QLatin1String("\" width=\"22\" height=\"22\">");
+        mText += QLatin1String(R"(" width="22" height="22">)");
         mText += i18n("Events:") + QLatin1String("</h2>\n");
         mText += QLatin1String("<table>\n");
         for (const KCalendarCore::Event::Ptr &ev : qAsConst(events)) {
@@ -201,7 +184,7 @@ void WhatsNextView::updateView()
                                   KIconLoader::DefaultState, QStringList(), &ipath);
                     mText += QLatin1String("<h2><img src=\"");
                     mText += ipath;
-                    mText += QLatin1String("\" width=\"22\" height=\"22\">");
+                    mText += QLatin1String(R"(" width="22" height="22">)");
                     mText += i18n("Events and to-dos that need a reply:")
                              + QLatin1String("</h2>\n");
                     mText += QLatin1String("<table>\n");
@@ -222,7 +205,7 @@ void WhatsNextView::updateView()
                                   KIconLoader::DefaultState, QStringList(), &ipath);
                     mText += QLatin1String("<h2><img src=\"");
                     mText += ipath;
-                    mText += QLatin1String("\" width=\"22\" height=\"22\">");
+                    mText += QLatin1String(R"(" width="22" height="22">)");
                     mText += i18n("Events and to-dos that need a reply:")
                              + QLatin1String("</h2>\n");
                     mText += QLatin1String("<table>\n");
